@@ -14,6 +14,8 @@ class HideCodeHTMLExporter(HTMLExporter):
         # self.preprocessors = ['hide_code.HideCodePreprocessor']
         # self._init_preprocessors()
 
+    export_from_notebook = 'Hide Code HTML'
+
     @default('template_file')
     def _template_file_default(self):
         return 'hide_code_full.tpl'
@@ -25,7 +27,17 @@ class HideCodeHTMLExporter(HTMLExporter):
         `./templates/` so append it to the search path. (see next section)
         """
         return super(HideCodeHTMLExporter, self).template_path + [os.path.join(os.path.dirname(__file__), "Templates")]
+        # return [os.path.join(os.path.dirname(__file__), "Templates")]
 
-    # @default('default_template_path')
-    # def _default_template_path_default(self):
+    # @default('template_path')
+    # def _default_template_path(self):
     #     return os.path.join(os.path.dirname(__file__), "Templates")
+
+    @property
+    def template_paths(self):
+        """
+        We want to inherit from HTML template, and have template under
+        ``./templates/`` so append it to the search path. (see next section)
+        Note: nbconvert 6.0 changed ``template_path`` to ``template_paths``
+        """
+        return super()._template_paths() + [os.path.join(os.path.dirname(__file__), "Templates")]
