@@ -10,8 +10,10 @@ class HideCodeSlidesExporter(SlidesExporter):
         self.preprocessors = ['hide_code.HideCodePreprocessor']
         self._init_preprocessors()
 
+    export_from_notebook = 'Hide Code Slides'
+
     def _template_file_default(self):
-        return 'hide_code_slides'
+        return 'hide_code_slides.tpl'
 
     @property
     def template_path(self):
@@ -20,3 +22,12 @@ class HideCodeSlidesExporter(SlidesExporter):
         `./templates/` so append it to the search path. (see next section)
         """
         return super(HideCodeSlidesExporter, self).template_path + [os.path.join(os.path.dirname(__file__), "Templates")]
+
+    @property
+    def template_paths(self):
+        """
+        We want to inherit from HTML template, and have template under
+        ``./templates/`` so append it to the search path. (see next section)
+        Note: nbconvert 6.0 changed ``template_path`` to ``template_paths``
+        """
+        return super()._template_paths() + [os.path.join(os.path.dirname(__file__), "Templates")]
\ No newline at end of file
